@@ -71,9 +71,7 @@ class AltListener(HasHosts):
 
 
 class EzElb(object):
-    def __init__(self, env_name, vpc_id, name=None, internal=False,
-                 tg_salt=None):
-
+    def __init__(self, env_name, vpc_id):
         self.env_name = env_name
         self.vpc_id = vpc_id
 
@@ -97,70 +95,13 @@ class EzElb(object):
         self._ecs_redirect = False
         self.idle_timeout_seconds = 120
         self._custom_elb_sgs = None
-        self._tg_salt = tg_salt
-
-        self._specified_elb_name = name
-        if name is None:
-            self._elb_name = Ref("AWS::StackName")
-        else:
-            self._elb_name = name
-
-        self._deletion_protection = False
-
-        if internal:
-            self._elb_scheme = "internal"
-        else:
-            self._elb_scheme = "internet-facing"
 
         self._sg_rules = [SecurityGroupRule(CidrIp="0.0.0.0/0", IpProtocol="tcp", FromPort=443, ToPort=443),
                           SecurityGroupRule(CidrIp="0.0.0.0/0", IpProtocol="tcp", FromPort=80, ToPort=80)]
 
-        # The first call to allow() should clear the default _sg_rules,
-        # subsequent calls should not.
+        # The first call to allow() should clear the default _sg_rules, subsequent calls should not.
         self._reset_sg_rules = True
 
-    #
-    # At the moment CloudFormation can't handle recreation of the ELB. When it
-    # tries to update listeners it fails because it tries to assign the
-    # target groups to the new ELB. This fails with:
-    #    cannot be associated with more than one load balancer
-    #
-    # This problem is described here:
-    #   https://forums.aws.amazon.com/thread.jspa?threadID=254544
-    #
-    # To work around this, we'll assign names to the target groups which change
-    # when the ELB name changes. If self._specified_elb_name == None then we
-    # won't specify a name for the target group.
-    #
-    # This leads to another issue if we have to replace a TargetGroup. Since we
-    # specified a name for the TG, then we'll need a way to change the name
-    # without changing the ELB name. To deal with this we add the tg_salt
-    # option to the constructor. If this is specified then it is added to the
-    # hashed string.
-    #
-    # Note that another way to deal with this would be to remove the target
-    # group and re-add it.
-    #
-    def name_target_group(self, tg):
-        if self._specified_elb_name is None:
-            return
-
-        # The maximum size for a TargetGroup name is 32 characters.
-        # Our name will be:
-        #     Stack name - up to 10 chars, dash
-        #   + TG title   - up to 10 chars, dash
-        #   + Hash
-        #   ------------ Truncated to 32 chars
-
-        hash_string = self._elb_name + tg.title
-        if self._tg_salt:
-            hash_string += str(self._tg_salt)
-
-        tg.Name = (self._elb_name[:10] + '-' + tg.title[:10] + '-' + hashlib.md5(hash_string).hexdigest())[:32]
-
-    def deletion_protection(self, p):
-        self._deletion_protection = p
-
     def allow(self, *rules):
         if self._reset_sg_rules:
             self._sg_rules = list(rules)
@@ -239,21 +180,13 @@ class EzElb(object):
 
     def elb_attributes(self):
         ret = [
-            LoadBalancerAttributes(Key="idle_timeout.timeout_seconds",
-                                   Value=str(self.idle_timeout_seconds)),
-            LoadBalancerAttributes(Key="routing.http2.enabled",
-                                   Value="true"),
-            LoadBalancerAttributes(Key="deletion_protection.enabled",
-                                   Value="true" if self._deletion_protection else "false")
+            LoadBalancerAttributes(Key="idle_timeout.timeout_seconds", Value=str(self.idle_timeout_seconds))
         ]
         if self._log_bucket is not None:
             ret += [
-                LoadBalancerAttributes(Key="access_logs.s3.enabled",
-                                       Value="true"),
-                LoadBalancerAttributes(Key="access_logs.s3.bucket",
-                                       Value=self._log_bucket),
-                LoadBalancerAttributes(Key="access_logs.s3.prefix",
-                                       Value=Sub("${AWS::StackName}-ElbLogs"))
+                LoadBalancerAttributes(Key="access_logs.s3.enabled", Value="true"),
+                LoadBalancerAttributes(Key="access_logs.s3.bucket", Value=self._log_bucket),
+                LoadBalancerAttributes(Key="access_logs.s3.prefix", Value=Sub("${AWS::StackName}-ElbLogs"))
             ]
         return ret
 
@@ -348,14 +281,6 @@ class EzElb(object):
                 raise ValidationException("Inconsistent target types for %s. All hosts for a given path must have the "
                                           "same type (ip or instance)." % name)
 
-        # Export VPC ID
-        self.template.add_output(Output(
-            "VpcIdExport",
-            Description="VPC of the ELB",
-            Value=self.vpc_id,
-            Export=Export(Sub("${AWS::StackName}-VpcId"))
-        ))
-
         # Build Security Group
         if self._custom_elb_sgs:
             elb_sgs = self._custom_elb_sgs
@@ -399,14 +324,12 @@ class EzElb(object):
         # Build ELB
         elb = LoadBalancer(
             "ELB",
+            Name=Ref("AWS::StackName"),
             SecurityGroups=elb_sgs,
-            Scheme=self._elb_scheme,
             Subnets=self.subnet_ids,
             Tags=self.tags_with(Name=Ref("AWS::StackName")),
             LoadBalancerAttributes=self.elb_attributes()
         )
-        if self._elb_name:
-            elb.Name = self._elb_name
         self.template.add_resource(elb)
         self.template.add_output(Output(
             "ElbArnOutput",
@@ -436,25 +359,17 @@ class EzElb(object):
             HealthyThresholdCount=2,
             Matcher=Matcher(HttpCode="200-399")
         )
-        self.name_target_group(default_tg)
         self.template.add_resource(default_tg)
         self.attach_alarm(default_tg)
 
         # Build Listener
-        listener = Listener(
+        self.template.add_resource(Listener(
             "HttpsListener",
             Certificates=list(map(lambda i: Certificate(CertificateArn=i), self.cert_ids)),
             DefaultActions=[Action(Type="forward", TargetGroupArn=Ref("DefaultTargetGroup"))],
             LoadBalancerArn=Ref("ELB"),
             Port=443,
             Protocol="HTTPS"
-        )
-        self.template.add_resource(listener)
-        self.template.add_output(Output(
-            "HttpsListenerExport",
-            Description="HTTPS Listener ARN",
-            Value=Ref(listener),
-            Export=Export(Sub("${AWS::StackName}-HttpsListener"))
         ))
 
         # Build HTTP redirect
@@ -470,7 +385,6 @@ class EzElb(object):
                 HealthyThresholdCount=2,
                 Matcher=Matcher(HttpCode="200-399")
             )
-            self.name_target_group(http_tg)
             self.template.add_resource(http_tg)
             self.attach_alarm(http_tg)
 
@@ -480,19 +394,12 @@ class EzElb(object):
             else:
                 redirect_tg = "RedirectTargetGroup"
             # Build Listener
-            http_listener = Listener(
+            self.template.add_resource(Listener(
                 "HttpListener",
                 DefaultActions=[Action(Type="forward", TargetGroupArn=Ref(redirect_tg))],
                 LoadBalancerArn=Ref("ELB"),
                 Port=80,
                 Protocol="HTTP"
-            )
-            self.template.add_resource(http_listener)
-            self.template.add_output(Output(
-                "HttpListenerExport",
-                Description="HTTP Listener ARN",
-                Value=Ref(http_listener),
-                Export=Export(Sub("${AWS::StackName}-HttpListener"))
             ))
 
         # Build Target Groups & Rules
@@ -511,7 +418,6 @@ class EzElb(object):
                 HealthyThresholdCount=2,
                 Matcher=tp.health_check_matcher
             )
-            self.name_target_group(g)
 
             # TODO: We should probably explicitly specify this for every TG. Not
             #       doing that now because it will cause lots of updates. Maybe
@@ -555,7 +461,6 @@ class EzElb(object):
                 HealthyThresholdCount=2,
                 Matcher=Matcher(HttpCode="200-399")
             )
-            self.name_target_group(tg)
             self.template.add_resource(tg)
             self.attach_alarm(tg)
 
